# mixer.py

[![Nuget](https://img.shields.io/pypi/v/mixer.py?color=%23FF00FF&style=for-the-badge)](https://pypi.org/project/mixer.py/)

An unofficial Mixer API wrapper written in Python.


### Disclaimer
As of August 2019, this project is still heavily under development.

Although it's already on PyPi, breaking changes will likely occur frequently until the release of 1.0.0.
